Graph tools
-------------

Graph classes
^^^^^^^^^^^^^

This module defines the classes to handle graphs.

.. automodule:: stochastic_matching.graphs.classes
    :members:

Generators
^^^^^^^^^^

Set of methods to produce graphs in various shapes.

.. automodule:: stochastic_matching.graphs.generators
    :members:

Display
^^^^^^^

Provides interface with vis-network (graph display).

.. automodule:: stochastic_matching.graphs.display
    :members:
